==> usocket-udp_1.0.tar.gz: usocket-udp-1.0/usocket-lispworks.lisp <==
;;;; -*- Mode: Lisp; Package: USOCKET; -*-

#|
<DOCUMENTATION>
 <DESCRIPTION>
  UDP support patch for USOCKET project. This file should sync with usocket-svn at

    svn://common-lisp.net/project/usocket/svn/usocket/trunk

  Waiting for USOCKET author to merge us.
  </DESCRIPTION>
 <COPYRIGHT YEAR='2007-2008' AUTHOR='Chun Tian (binghe)' MARK='(C)'
            HREF='https://cl-net-snmp.svn.sourceforge.net/svnroot/cl-net-snmp/usocket-udp/trunk/usocket-lispworks.lisp'/>
 <CHRONOLOGY>
  <DELTA DATE='20080402'>move to standalone usocket-udp subproject</DELTA>
  <DELTA DATE='20080317'>create USOCKET UDP patch file "usocket-lispworks.lisp"</DELTA>
  </CHRONOLOGY>
 </DOCUMENTATION>
|#

(in-package :usocket)

(defun socket-connect/udp (host port &key (stream nil) (element-type 'base-char))
  (if (and host port)
    (if stream
      (let ((stream (comm:open-udp-stream host port
                                          :element-type element-type
                                          :errorp nil)))
        (make-stream-datagram-socket
         (comm:socket-stream-socket stream) stream))
      (make-datagram-socket (comm:connect-to-udp-server host port :errorp nil)
			    :connected-p t))
    (make-datagram-socket (comm:open-udp-socket :errorp nil)
			  :connected-p nil)))

(defmethod socket-send ((socket datagram-usocket) buffer length &key address port)
  (let ((s (socket socket)))
    (comm:send-message s buffer length address port)))

(defmethod socket-receive ((socket datagram-usocket) buffer length)
  (let ((s (socket socket)))
    (comm:receive-message s buffer length)))

:eof

==> usocket-udp_1.1.tar.gz: usocket-udp-1.1/usocket-lispworks.lisp <==
;;;; -*- Mode: Lisp; Package: USOCKET; -*-

#|
<DOCUMENTATION>
 <DESCRIPTION>
  UDP support patch for USOCKET project. This file should sync with usocket-svn at

    svn://common-lisp.net/project/usocket/svn/usocket/trunk

  Waiting for USOCKET author to merge us.
  </DESCRIPTION>
 <COPYRIGHT YEAR='2007-2008' AUTHOR='Chun Tian (binghe)' MARK='(C)'
            HREF='https://cl-net-snmp.svn.sourceforge.net/svnroot/cl-net-snmp/usocket-udp/trunk/usocket-lispworks.lisp'/>
 <CHRONOLOGY>
  <DELTA DATE='20080402'>move to standalone usocket-udp subproject</DELTA>
  <DELTA DATE='20080317'>create USOCKET UDP patch file "usocket-lispworks.lisp"</DELTA>
  </CHRONOLOGY>
 </DOCUMENTATION>
|#

(in-package :usocket)

(defun socket-connect/udp (host port &key (stream nil) (element-type 'base-char)
			                  (errorp t) local-address local-port)
  (if (and host port)
    (if stream
      (let ((stream (comm:open-udp-stream host port
                                          :element-type element-type
                                          :errorp errorp
					  :local-address local-address
					  :local-port local-port)))
        (make-stream-datagram-socket
         (comm:socket-stream-socket stream) stream))
      (make-datagram-socket (comm:connect-to-udp-server host port
							:errorp errorp
							:local-address local-address
							:local-port local-port)
			    :connected-p t))
    (make-datagram-socket (comm:open-udp-socket :errorp errorp
						:local-address local-address
						:local-port local-port)
			  :connected-p nil)))

(defmethod socket-send ((socket datagram-usocket) buffer length &key address port)
  (let ((s (socket socket)))
    (comm:send-message s buffer length address port)))

(defmethod socket-receive ((socket datagram-usocket) buffer length)
  (let ((s (socket socket)))
    (comm:receive-message s buffer length)))

:eof
